/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#include "config/option/pingfaillimitoption.h"

#include <logfunc.hpp>

using namespace std;
using boost::program_options::value;
using boost::program_options::variables_map;
using I2n::Logger::GlobalLogger;

//-----------------------------------------------------------------------------
// PingFailLimitOption
//-----------------------------------------------------------------------------

PingFailLimitOption::PingFailLimitOption() :
    ConfigurationOption(
        "ping-fail-limit",
        value<int>()->default_value( 50 ), // 50 pings can fail at most
        "Maximum percentage of pings that can fail for a given host."
    )
{
}

PingFailLimitOption::~PingFailLimitOption()
{
}

bool PingFailLimitOption::parse(
        const variables_map& vm,
        Configuration *configuration
)
{
    // ping-fail-limit
    if ( 1 <= vm.count( get_command_string() ) )
    {
        int ping_fail_limit = vm[ get_command_string() ].as<int> ();
        configuration->set_ping_fail_limit( ping_fail_limit );

        GlobalLogger.info() << get_command_string() << "="
                << ping_fail_limit << endl;

        return true;
    }

    return false;
}
